@@ -4,10 +4,8 @@ from ._DeepLearningNewsvendor import DeepLearningNewsvendor
 from ._WeightedNewsvendor import DecisionTreeWeightedNewsvendor, RandomForestWeightedNewsvendor, \
     KNeighborsWeightedNewsvendor, GaussianWeightedNewsvendor
 from ._ExponentialSmoothingNewsvendor import ExponentialSmoothingNewsvendor
-from ._MLPNewsvendor import MLPNewsvendor
 
 __all__ = ["SampleAverageApproximationNewsvendor", "LinearRegressionNewsvendor",
            "DeepLearningNewsvendor", "DecisionTreeWeightedNewsvendor",
            "RandomForestWeightedNewsvendor", "KNeighborsWeightedNewsvendor",
-           "GaussianWeightedNewsvendor", "ExponentialSmoothingNewsvendor",
-           "MLPNewsvendor"]
+           "GaussianWeightedNewsvendor", "ExponentialSmoothingNewsvendor"]
